package cofh.thermal.expansion.compat.jei.machine;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import cofh.core.fluid.PotionFluid;
import cofh.core.init.CoreFluids;
import cofh.lib.fluid.FluidIngredient;
import cofh.thermal.core.util.managers.machine.BottlerRecipeManager;
import cofh.thermal.core.util.recipes.machine.BottlerRecipe;
import cofh.thermal.expansion.compat.jei.TExpJeiPlugin;
import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import mezz.jei.api.constants.VanillaTypes;
import mezz.jei.api.forge.ForgeTypes;
import mezz.jei.api.ingredients.IIngredientType;
import mezz.jei.api.recipe.IFocus;
import mezz.jei.api.recipe.RecipeIngredientRole;
import mezz.jei.api.recipe.RecipeType;
import mezz.jei.api.recipe.advanced.IRecipeManagerPlugin;
import mezz.jei.api.recipe.category.IRecipeCategory;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.world.item.ItemStack;
import net.minecraft.world.item.Items;
import net.minecraft.world.item.alchemy.Potion;
import net.minecraft.world.item.alchemy.Potions;
import net.minecraft.world.item.crafting.Ingredient;
import net.minecraft.world.level.ItemLike;
import net.minecraftforge.fluids.FluidStack;
import net.minecraftforge.registries.ForgeRegistries;
import org.jetbrains.annotations.NotNull;

public class PotionFluidRecipeManagerPlugin implements IRecipeManagerPlugin {
  public <V> List<RecipeType<?>> getRecipeTypes(IFocus<V> focus) {
    return List.of(TExpJeiPlugin.BOTTLER);
  }
  
  public <T, V> List<T> getRecipes(IRecipeCategory<T> recipeCategory, IFocus<V> focus) {
    if (recipeCategory instanceof cofh.thermal.expansion.compat.jei.machine.BottlerRecipeCategory) {
      List<BottlerRecipe> retList = new ArrayList<>();
      if (focus.getRole() == RecipeIngredientRole.INPUT) {
        Optional<FluidStack> fluidIngredient = focus.getTypedValue().getIngredient((IIngredientType)ForgeTypes.FLUID_STACK);
        if (fluidIngredient.isPresent() && ((FluidStack)fluidIngredient.get()).getFluid() == CoreFluids.POTION_FLUID.get()) {
          FluidStack fluid = fluidIngredient.get();
          if (fluid.hasTag()) {
            ItemStack item = new ItemStack((ItemLike)Items.f_42589_);
            item.m_41751_(fluid.getTag().m_6426_());
            retList.add(getDynamicBottlerPotionRecipe(item, fluid));
          } 
        } 
      } else if (focus.getRole() == RecipeIngredientRole.OUTPUT) {
        Optional<ItemStack> ingredient = focus.getTypedValue().getIngredient(VanillaTypes.ITEM);
        if (ingredient.isPresent() && ((ItemStack)ingredient.get()).m_41720_() == Items.f_42589_) {
          ItemStack item = ingredient.get();
          if (item.m_41782_()) {
            FluidStack fluid = PotionFluid.getPotionFluidFromItem(250, item);
            retList.add(getDynamicBottlerPotionRecipe(item, fluid));
          } 
        } 
      } 
      return (List)retList;
    } 
    return List.of();
  }
  
  public <T> List<T> getRecipes(IRecipeCategory<T> recipeCategory) {
    if (recipeCategory instanceof cofh.thermal.expansion.compat.jei.machine.BottlerRecipeCategory) {
      if (this.bottlerRecipes.isEmpty())
        for (Potion potion : ForgeRegistries.POTIONS) {
          if (potion != null && potion != Potions.f_43599_ && potion != Potions.f_43598_) {
            FluidStack fluid = PotionFluid.getPotionAsFluid(250, potion);
            if (fluid.isEmpty())
              continue; 
            ItemStack item = new ItemStack((ItemLike)Items.f_42589_);
            item.m_41751_(fluid.getTag());
            this.bottlerRecipes.add(getDynamicBottlerPotionRecipe(item, fluid));
          } 
        }  
      return (List)this.bottlerRecipes;
    } 
    return List.of();
  }
  
  public <V> List<ResourceLocation> getRecipeCategoryUids(IFocus<V> focus) {
    return List.of(TExpJeiPlugin.BOTTLER.getUid());
  }
  
  private final List<BottlerRecipe> bottlerRecipes = new ArrayList<>();
  
  @NotNull
  private BottlerRecipe getDynamicBottlerPotionRecipe(ItemStack item, FluidStack fluid) {
    return new BottlerRecipe(new ResourceLocation("thermal", "bottler_potion_" + item.hashCode()), 
        BottlerRecipeManager.instance().getDefaultEnergy(), 0.0F, 
        List.of(Ingredient.m_43929_(new ItemLike[] { (ItemLike)Items.f_42590_ }, )), List.of(FluidIngredient.of(new FluidStack[] { fluid }, ).setAmount(250)), 
        List.of(item), 
        List.of(Float.valueOf(1.0F)), 
        List.of());
  }
}
